#!/usr/bin/python3

import glob
import os
import shutil
import subprocess
import time



def crea_dir():
    #basedest = "/home/facundo/sistema/remote-data/fotos/"
    basedest = "/home/facundo/sistema/fotos/"
    if os.path.exists(basedest):
        newdir = time.strftime("%Y%m%d%H%M%S")
        destin = os.path.join(basedest, newdir)
    else:
        destin = os.path.expanduser("~/fotoscamara")

    print("Usando el directorio", repr(destin))
    os.makedirs(destin)
    return destin


def get_mass_storage(basedir):
    destin = crea_dir()

    # get to the real dir
    subd1 = os.listdir(basedir)
    assert subd1 == ["DCIM"]
    subd2 = os.listdir(os.path.join(basedir, "DCIM"))
    assert len(subd2) == 1
    origen = os.path.join(basedir, "DCIM", subd2[0])

    # tomamos los dirs
    archs = os.listdir(origen)
    for arch in archs:
        orig = os.path.join(origen, arch)
        dest = os.path.join(destin, arch)
        try:
            shutil.copy2(orig, dest)
        except OSError:
            print("ERROR con", repr(arch))
            if os.path.exists(dest):
                os.unlink(dest)
            return

        print(orig, dest)

    print("Terminado! Todo en:", destin)


def get_canon():
    # creamos el new dir y vamos
    newdir = crea_dir()
    os.chdir(newdir)

    # traemos todo. Nota: no conviene traer de a uno usando gphoto2 desde linea
    # de comando, porque para cada llamada hay toda una inicialización de
    # la cámara
    subprocess.run(["gphoto2", "--get-all-files"])

    # renombramos
    archivos = glob.glob("IMG*.JPG")
    archivos.extend(glob.glob("IMG*.MVI"))
    archivos.extend(glob.glob("MVI*.MOV"))
    archivos.extend(glob.glob("MVI*.MP4"))
    print("Renombrando %d archivos..." % len(archivos))
    for oldname in archivos:
        newname = "%s8%s" % tuple(oldname.split("_"))
        os.rename(oldname, newname)

    print("Todo en:", newdir)


def main():
    proc = subprocess.run(["gphoto2", "--auto-detect"], capture_output=True, encoding='utf8')
    for lin in proc.stdout.split('\n'):
        canon = ("USB PTP Class Camera", "Canon PowerShot", "Canon EOS 7D")
        if any(lin.startswith(x) for x in canon):
            print("Encontrada la", lin)
            get_canon()
            return

        if lin.startswith("Mass Storage Camera"):
            print("Encontrada la", lin)
            _, basedir = lin.strip().split("disk:")
            get_mass_storage(basedir)
            return

    # oops
    print("No se encontró ninguna cámara conectada!")


if __name__ == "__main__":
    main()
